/***********************************************************************************************************************************
LZ4 Common
***********************************************************************************************************************************/
#ifndef COMMON_COMPRESS_LZ4_COMMON_H
#define COMMON_COMPRESS_LZ4_COMMON_H

/***********************************************************************************************************************************
LZ4 extension
***********************************************************************************************************************************/
#define LZ4_EXT                                                     "lz4"

#ifdef HAVE_LIBLZ4

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Process lz4 errors
FN_EXTERN size_t lz4Error(size_t error);

#endif // HAVE_LIBLZ4

#endif
